---
title: <span class="badge object-type-enum"></span> TableCellBackgroundDisplayMode
---
# <span class="badge object-type-enum"></span> TableCellBackgroundDisplayMode

Display mode to the "Colored Background" display

mode for table cells. Either displays a solid color (basic mode)

or a gradient.

## Definition

```python
class TableCellBackgroundDisplayMode(enum.StrEnum):
    """
    Display mode to the "Colored Background" display
    mode for table cells. Either displays a solid color (basic mode)
    or a gradient.
    """

    BASIC = "basic"
    GRADIENT = "gradient"
```
